@@ -28,8 +28,8 @@ static void destroyScrollView(ScrollView * sPtr);
 static void paintScrollView(ScrollView * sPtr);
 static void handleEvents(XEvent * event, void *data);
 static void handleViewportEvents(XEvent * event, void *data);
-static void resizeScrollView();
-static void updateScrollerProportion();
+static void resizeScrollView(W_ViewDelegate *self, WMView *view);
+static void updateScrollerProportion(ScrollView *sPtr);
 
 W_ViewDelegate _ScrollViewViewDelegate = {
 	NULL,
@@ -199,6 +199,9 @@ static void reorganizeInterior(WMScrollView * sPtr)
 
 static void resizeScrollView(W_ViewDelegate * self, WMView * view)
 {
+	/* Parameter not used, but tell the compiler that it is ok */
+	(void) self;
+
 	reorganizeInterior(view->self);
 	updateScrollerProportion(view->self);
 }
@@ -503,10 +506,10 @@ static void updateScrollerProportion(ScrollView * sPtr)
 
 		prop = (float)sPtr->viewport->size.width / (float)sPtr->contentView->size.width;
 
-		if (oldP == 1.0)
-			value = 0;
-		else
+		if (oldP < 1.0)
 			value = (prop * oldV) / oldP;
+		else
+			value = 0;
 		WMSetScrollerParameters(sPtr->hScroller, value, prop);
 	}
 	if (sPtr->flags.hasVScroller) {
@@ -515,10 +518,10 @@ static void updateScrollerProportion(ScrollView * sPtr)
 
 		prop = (float)sPtr->viewport->size.height / (float)sPtr->contentView->size.height;
 
-		if (oldP == 1.0)
-			value = 0;
-		else
+		if (oldP < 1.0)
 			value = (prop * oldV) / oldP;
+		else
+			value = 0;
 		WMSetScrollerParameters(sPtr->vScroller, value, prop);
 	}
 	applyScrollerValues(sPtr);
