@@ -22,13 +22,13 @@
 #define WMDEFAULTS_H_
 
 typedef struct WDDomain {
-	char *domain_name;
+	const char *domain_name;
 	WMPropList *dictionary;
-	char *path;
+	const char *path;
 	time_t timestamp;
 } WDDomain;
 
-WDDomain * wDefaultsInitDomain(char *domain, Bool requireDictionary);
+WDDomain * wDefaultsInitDomain(const char *domain, Bool requireDictionary);
 
 void wDefaultsMergeGlobalMenus(WDDomain *menuDomain);
 
@@ -37,21 +37,24 @@ void wDefaultUpdateIcons(WScreen *scr);
 void wReadStaticDefaults(WMPropList *dict);
 void wDefaultsCheckDomains(void *arg);
 void wSaveDefaults(WScreen *scr);
-void wDefaultFillAttributes(char *instance, char *class,
+void wDefaultFillAttributes(const char *instance, const char *class,
                             WWindowAttributes *attr, WWindowAttributes *mask,
                             Bool useGlobalDefault);
 
 char *get_default_image_path(void);
 RImage *get_default_image(WScreen *scr);
 
-char *wDefaultGetIconFile(char *instance, char *class, Bool default_icon);
+char *wDefaultGetIconFile(const char *instance, const char *class, Bool default_icon);
 
-RImage *get_icon_image(WScreen *scr, char *winstance, char *wclass, int max_size);
-char *get_icon_filename(WScreen *scr, char *winstance, char *wclass, char *command,
+RImage *get_icon_image(WScreen *scr, const char *winstance, const char *wclass, int max_size);
+char *get_icon_filename(const char *winstance, const char *wclass, const char *command,
 			Bool default_icon);
 
 
-int wDefaultGetStartWorkspace(WScreen *scr, char *instance, char *class);
-void wDefaultChangeIcon(WScreen *scr, char *instance, char* class, char *file);
-RImage *get_rimage_from_file(WScreen *scr, char *file_name, int max_size);
+int wDefaultGetStartWorkspace(const char *instance, const char *class);
+void wDefaultChangeIcon(const char *instance, const char* class, const char *file);
+RImage *get_rimage_from_file(WScreen *scr, const char *file_name, int max_size);
+
+void wDefaultPurgeInfo(const char *instance, const char *class);
+
 #endif /* WMDEFAULTS_H_ */
